Module: GLCommand::Matchers
- Defined in:
- lib/gl_command/rspec/matchers.rb
Defined Under Namespace
Classes: AllowArgumentMatcher, CommandArgumentMatcher, RequireArgumentMatcher, ReturnAttributeMatcher
Instance Method Summary collapse
- #allow(attribute) ⇒ Object
-
#require(attribute) ⇒ Object
Helper methods to provide the clean syntax in specs.
- #returns(attribute) ⇒ Object
Instance Method Details
#allow(attribute) ⇒ Object
105 106 107 |
# File 'lib/gl_command/rspec/matchers.rb', line 105 def allow(attribute) AllowArgumentMatcher.new(attribute) end |
#require(attribute) ⇒ Object
Helper methods to provide the clean syntax in specs
101 102 103 |
# File 'lib/gl_command/rspec/matchers.rb', line 101 def require(attribute) RequireArgumentMatcher.new(attribute) end |
#returns(attribute) ⇒ Object
109 110 111 |
# File 'lib/gl_command/rspec/matchers.rb', line 109 def returns(attribute) ReturnAttributeMatcher.new(attribute) end |